"""
hudai.resources
"""

from .article import ArticleResource
from .article_company import ArticleCompanyResource
from .article_highlights import ArticleHighlightsResource
from .article_key_term import ArticleKeyTermResource
from .article_tag import ArticleTagResource
from .collateral import CollateralResource
from .company import CompanyResource
from .company_event import CompanyEventResource
from .company_industry import CompanyIndustryResource
from .company_key_term import CompanyKeyTermResource
from .company_profile import CompanyProfileResource
from .domain import DomainResource
from .industry import IndustryResource
from .key_term import KeyTermResource
from .organization import OrganizationResource
from .person import PersonResource
from .person_key_term import PersonKeyTermResource
from .person_quote import PersonQuoteResource
from .relevant_article_collateral import RelevantArticleCollateralResource
from .relevant_articles import RelevantArticlesResource
from .source import SourceResource
from .stock_alert import StockAlertResource
from .system_event import SystemEventResource
from .system_task import SystemTaskResource
from .text_corpus import TextCorpusResource
from .tweets import TweetResource
from .user import UserResource
from .user_company import UserCompanyResource
from .user_company_group import UserCompanyGroupResource
from .user_contact import UserContactResource
from .user_digest_subscription import UserDigestSubscriptionResource
from .user_key_term import UserKeyTermResource
from .user_source import UserSourceResource